package Locale::CLDR::Locales::It::Any;

# This file auto generated
#	on Sun  7 Jan  2:30:41 pm GMT

use version;

our $VERSION = version->declare('v0.40.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::It');

no Moo;

1;
